@@ -49,12 +49,13 @@
 #include "models/feedsproxymodel.h"
 #include "models/podcastsearchmodel.h"
 #include "models/queuemodel.h"
-#include "networkconnectionmanager.h"
 #include "settingsmanager.h"
-#include "storagemanager.h"
 #include "sync/sync.h"
 #include "sync/syncutils.h"
-#include "systrayicon.h"
+#include "utils/colorschemer.h"
+#include "utils/networkconnectionmanager.h"
+#include "utils/storagemanager.h"
+#include "utils/systrayicon.h"
 
 #ifdef Q_OS_WINDOWS
 #include <windows.h>
@@ -70,11 +71,6 @@ int main(int argc, char *argv[])
         qputenv("QT_ENABLE_GLYPH_CACHE_WORKAROUND", "1");
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
-
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
     qInstallMessageHandler(myMessageHandler);
@@ -163,6 +159,10 @@ int main(int argc, char *argv[])
     qmlRegisterSingletonInstance("org.kde.kasts", 1, 0, "StorageManager", &StorageManager::instance());
     qmlRegisterSingletonInstance("org.kde.kasts", 1, 0, "Sync", &Sync::instance());
     qmlRegisterSingletonInstance("org.kde.kasts", 1, 0, "SystrayIcon", &SystrayIcon::instance());
+    qmlRegisterSingletonInstance<ColorSchemer>("org.kde.kasts", 1, 0, "ColorSchemer", &ColorSchemer::instance());
+    if (SettingsManager::self()->colorScheme().isEmpty()) {
+        ColorSchemer::instance().apply(SettingsManager::self()->colorScheme());
+    }
 
     qmlRegisterUncreatableMetaObject(SyncUtils::staticMetaObject, "org.kde.kasts", 1, 0, "SyncUtils", QStringLiteral("Error: only enums and structs"));
 
